summaryrefslogtreecommitdiffstats
path: root/xlators/cluster/ec/src/ec-common.c
diff options
context:
space:
mode:
authorPranith Kumar K <pkarampu@redhat.com>2015-05-18 14:46:55 +0530
committerPranith Kumar Karampuri <pkarampu@redhat.com>2015-05-19 02:05:04 -0700
commit64d2a5a25b64601958c0f47ec2e6356226f97d4b (patch)
tree17d702ee851e801d061cd0fdc73ee5ed038c1547 /xlators/cluster/ec/src/ec-common.c
parent6cbbe121e8d14342a17f38fb9f616a396550fb63 (diff)
cluster/ec: Handle lookup failures while op in progress
Change-Id: Ia1834ec23d5de615526d4d4e4d2e32aff155b7f7 BUG: 1211962 Signed-off-by: Pranith Kumar K <pkarampu@redhat.com> Reviewed-on: http://review.gluster.org/10806 Tested-by: NetBSD Build System Tested-by: Gluster Build System <jenkins@build.gluster.com> Reviewed-by: Xavier Hernandez <xhernandez@datalab.es>
Diffstat (limited to 'xlators/cluster/ec/src/ec-common.c')
-rw-r--r--xlators/cluster/ec/src/ec-common.c16
1 files changed, 9 insertions, 7 deletions
diff --git a/xlators/cluster/ec/src/ec-common.c b/xlators/cluster/ec/src/ec-common.c
index 393d9142797..afd46c095f3 100644
--- a/xlators/cluster/ec/src/ec-common.c
+++ b/xlators/cluster/ec/src/ec-common.c
@@ -1206,14 +1206,16 @@ void ec_get_size_version(ec_fop_data_t * fop)
loc.path = NULL;
loc.name = NULL;
}
/* For normal fops, ec_lookup() must succeed on at least EC_MINIMUM_MIN
* bricks, however when this is called as part of a self-heal operation
* the mask of target bricks (fop->mask) could contain less than
* EC_MINIMUM_MIN bricks, causing the lookup to always fail. Thus we
* always use the same minimum used for the main fop.
*/
- ec_lookup(fop->frame, fop->xl, fop->mask, fop->minimum,
- ec_get_size_version_set, NULL, &loc, xdata);
+ ec_xattrop (fop->frame, fop->xl, fop->mask, fop->minimum,
+ ec_prepare_update_cbk, NULL, &loc,
+ GF_XATTROP_ADD_ARRAY64, xdata, NULL);
} else {
if (ec_loc_from_fd(fop->xl, &loc, fop->fd) != 0) {
goto out;
@@ -1206,14 +1206,16 @@ void ec_get_size_version(ec_fop_data_t * fop)
loc.name = NULL;
}
- /* For normal fops, ec_lookup() must succeed on at least EC_MINIMUM_MIN
- * bricks, however when this is called as part of a self-heal operation
- * the mask of target bricks (fop->mask) could contain less than
- * EC_MINIMUM_MIN bricks, causing the lookup to always fail. Thus we
- * always use the same minimum used for the main fop.
+ /* For normal fops, ec_[f]xattrop() must succeed on at least
+ * EC_MINIMUM_MIN bricks, however when this is called as part of
+ * a self-heal operation the mask of target bricks (fop->mask) could
+ * contain less than EC_MINIMUM_MIN bricks, causing the lookup to
+ * always fail. Thus we always use the same minimum used for the main
+ * fop.
*/